@@ -481,11 +481,9 @@ ephy_embed_prefs_init (void)
 
   /* Hardcoded settings */
   g_object_set (webkit_settings,
-                "auto-shrink-images", FALSE,
                 "enable-default-context-menu", FALSE,
                 "enable-site-specific-quirks", TRUE,
                 "enable-page-cache", TRUE,
-                "auto-resize-window", TRUE,
                 "enable-developer-extras", TRUE,
                 NULL);
 
