@@ -105,39 +105,17 @@ ephy_file_tmp_dir (void)
 	return tmp_dir;
 }
 
-/**
- * ephy_file_downloads_dir:
- *
- * Gets the basename for Epiphany's Downloads dir. This depends on the current
- * locale. For the full path to the downloads directory see
- * ephy_file_get_downloads_dir().
- *
- * Returns: a newly-allocated string containing the downloads dir basename.
- **/
-char *
-ephy_file_downloads_dir (void)
+static char *
+ephy_file_download_dir (void)
 {
-	const char *translated_folder;
 	const char *xdg_download_dir;
-	char *desktop_dir, *converted, *downloads_dir;
 
 	xdg_download_dir = g_get_user_special_dir (G_USER_DIRECTORY_DOWNLOAD);
 	if (xdg_download_dir != NULL)
 		return g_strdup (xdg_download_dir);
 
-	/* The name of the default downloads folder */
-	translated_folder = _("Downloads");
-
-	converted = g_filename_from_utf8 (translated_folder, -1, NULL,
-					  NULL, NULL);
-
-	desktop_dir = ephy_file_desktop_dir ();
-	downloads_dir = g_build_filename (desktop_dir, converted, NULL);
-
-	g_free (desktop_dir);
-	g_free (converted);
-
-	return downloads_dir;
+	/* If we don't have XDG user dirs info, return an educated guess. */
+	return g_build_filename	(g_get_home_dir (), _("Downloads"), NULL);
 }
 
 /**
@@ -152,44 +130,18 @@ ephy_file_downloads_dir (void)
 char *
 ephy_file_get_downloads_dir (void)
 {
-	char *download_dir, *expanded;
+	char *download_dir;
 
 	download_dir = g_settings_get_string (EPHY_SETTINGS_STATE,
 					      EPHY_PREFS_STATE_DOWNLOAD_DIR);
 
-	if (download_dir && strcmp (download_dir, _("Downloads")) == 0)
-	{
-		g_free (download_dir);
-		download_dir = ephy_file_downloads_dir ();
-	}
-  	else if (download_dir && strcmp (download_dir, _("Desktop")) == 0)
-	{
-		g_free (download_dir);
-		download_dir = ephy_file_desktop_dir ();
-	}
-	else if (download_dir)
-	{
-		char *converted_dp;
-
-		converted_dp = g_filename_from_utf8 (download_dir, -1, NULL, NULL, NULL);
-		g_free (download_dir);
-		download_dir = converted_dp;
-	}
-
 	/* Emergency download destination */
-	if (download_dir == NULL)
-	{
-		const char *home_dir;
-		home_dir = g_get_home_dir ();
-		download_dir = g_strdup (home_dir != NULL ? home_dir : "/");
-	}
+	if (g_str_equal (download_dir, "Downloads"))
+		download_dir = ephy_file_download_dir ();
+	else if (g_str_equal (download_dir, "Desktop") || g_path_is_absolute (download_dir) != TRUE)
+		download_dir = ephy_file_desktop_dir ();
 
-	g_return_val_if_fail (download_dir != NULL, NULL);
-
-	expanded = ephy_string_expand_initial_tilde (download_dir);
-	g_free (download_dir);
-
-	return expanded;
+	return download_dir;
 }
 
 /**
@@ -275,6 +227,7 @@ ephy_file (const char *filename)
 #ifdef GNOME_ENABLE_DEBUG
 		SHARE_UNINSTALLED_DIR "/",
 		SHARE_UNINSTALLED_DIR "/glade/",
+		SHARE_UNINSTALLED_DIR "/ui/",
 		SHARE_UNINSTALLED_DIR "/art/",
 		SHARE_UNINSTALLED_DIR "/pages/",
 #endif
@@ -910,29 +863,16 @@ gboolean
 ephy_file_browse_to (GFile *file,
 		     guint32 user_time)
 {
-	GFile *parent, *desktop;
-	char *desktop_dir;
+	GFile *parent;
 	gboolean ret;
 
-	desktop_dir = ephy_file_desktop_dir ();
-	desktop = g_file_new_for_path (desktop_dir);
-	
-	/* Don't do anything if destination is the desktop */
-	if (g_file_has_prefix (file, desktop))
-	{
-		ret = FALSE;
-	}
-	else
-	{
-		parent = g_file_get_parent (file);
-		/* TODO find a way to make nautilus scroll to the actual file */
-		ret = ephy_file_launch_handler ("x-directory/normal",
-						parent,
-						user_time);
-	}
+	parent = g_file_get_parent (file);
+	/* TODO find a way to make nautilus scroll to the actual file */
+	ret = ephy_file_launch_handler ("x-directory/normal",
+					parent,
+					user_time);
 
-	g_object_unref (desktop);
-	g_free (desktop_dir);
+	g_object_unref (parent);
 
 	return ret;
 }
